#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Intl;

use strict;
use Vhffs::Main;

sub get_languages
{
	my $vhffs = shift;
	my $langs;
	my @langs;
	my $file;
	my $dir = $vhffs->get_config->get_intldir;

	opendir( DIR , $dir );
	my @files = readdir( DIR );

	foreach( @files )
	{
		next if( ! -d $dir."/".$_ );	#next if the file is not a directory
									#languages files are in a directory
		next if( /^\./ );			#next if found language is .svn or . or ..
		push( @langs , $_ );
	}

	closedir( DIR );
	return \@langs;
}

1;

__END__

=head1 NAME

Vhffs::Intl - Intl class of Vhffs API

=head1 SYNOPSIS

	use Vhffs::Intl;
	my $langs = $get_languages;
	foreach $l ( @$langs )
	{
		echo $l;
	}

=head1 DESCRIPTION
Functions around intl

=head1 METHODS

=head1 SEE ALSO
Vhffs::User, Vhffs::Group, Vhffs::Panel::Main

=head1 AUTHOR

	Julien Delange <julien at gunnm dot org>

=head1 COPYRIGHT

	Copyright 2005 by Julien Delange

