#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::Menu;

use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Group;
use Vhffs::Panel::Web;
use Vhffs::Panel::Mysql;
use Vhffs::Panel::Pgsql;
use Vhffs::Panel::Cvs;
use Vhffs::Panel::DNS;
use Vhffs::Panel::Mail;
use Vhffs::Panel::Mailinglist;
use Vhffs::Panel::LargeFile;
use Vhffs::Panel::Repository;

sub new
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $cgi = $data->{'cgi'};
	my $theme = $data->{'theme'};
	my $templatedir = $vhffs->get_config->get_templatedir;
	my $menu;

	my $menutemplate = new HTML::Template( filename => $templatedir."/menu/main.tmpl" );

	$menutemplate->param( THEME => $theme );

	if( $user->is_admin == 1 )
	{
		$menutemplate->param( TEXT_ACCOUNT    => gettext("Admin account : ") );
	}
	elsif( $user->is_moderator == 1 )
	{
		$menutemplate->param( TEXT_ACCOUNT    => gettext("Moderator account : ") );
	}
	else
	{
		$menutemplate->param( TEXT_ACCOUNT    => gettext("User account : ") );
	}
	$menutemplate->param( USERNAME        => $user->get_username() );

	# add the User account
	my $usertemplate = new HTML::Template( filename => $templatedir."/menu/user.tmpl" );
	$usertemplate->param( TEXT_PREFS      => gettext("User Preferences") );
	$usertemplate->param( TEXT_HELP       => gettext("Help") );
	$usertemplate->param( TEXT_SUBMITBUG  => gettext("Submit a bug") );
	$usertemplate->param( TEXT_LOGOUT     => gettext("Logout") );
	if( defined $vhffs->get_config->get_panel_helpurl )
	{
	    $usertemplate->param( HELP_URL        => $vhffs->get_config->get_panel_helpurl );
	}
	else
	{
	    $usertemplate->param( HELP_URL        => "nolink" );
	}
	

	#Admin
	if( ( $user->is_admin == 1) || ( $user->is_moderator == 1 ) )
	{
		use Vhffs::Panel::Admin;	
		$menutemplate->param( ADMIN_MENU => menu Vhffs::Panel::Admin( $data ) );
	}
	else
	{
		$menutemplate->param( ADMIN_MENU => "" );
	}

	# Group
	my $groupmenu = menu Vhffs::Panel::Group($data);

	my $projectname = $session->param("project");
	$usertemplate->param( GROUP => $groupmenu );
	$menutemplate->param( USER_MENU => $usertemplate->output );
	if( $projectname )  {

		my $projecttemplate = new HTML::Template( filename => $templatedir."/menu/group.tmpl" );
		$projecttemplate->param( PROJECTNAME      => $projectname );
		$projecttemplate->param( SHOW_HIDE      => gettext("Show/Hide") );
		$projecttemplate->param( TEXT_PROJECT     => gettext("Project : ") );
		$projecttemplate->param( TEXT_CONFIG      => gettext("Project Configuration") );

		# Web
		if( $vhffs->get_config->use_web == 1 )
		{
			my $webmenu = menu Vhffs::Panel::Web($data);
			$projecttemplate->param( WEB_MENU => $webmenu );
		}

		# MySQL
		if( $vhffs->get_config->use_mysql == 1 )
		{
			my $mysqlmenu = menu Vhffs::Panel::Mysql($data);
			$projecttemplate->param( MYSQL_MENU => $mysqlmenu );
		}

		# PGSQL
		if( $vhffs->get_config->use_postgres == 1 )
		{
			my $pgsqlmenu = menu Vhffs::Panel::Pgsql($data);
			$projecttemplate->param( PGSQL_MENU => $pgsqlmenu );
		}

		# CVS
		if( $vhffs->get_config->use_cvs == 1 )
		{
			my $cvsmenu = menu Vhffs::Panel::Cvs($data);
			$projecttemplate->param( CVS_MENU => $cvsmenu );
		}


		# SVN 
		if( $vhffs->get_config->use_svn == 1 )
		{
			use Vhffs::Panel::Svn;
			my $svnmenu = menu Vhffs::Panel::Svn($data);
			$projecttemplate->param( SVN_MENU => $svnmenu );
		}



		# DNS
		if( $vhffs->get_config->use_dns == 1 )
		{
			my $dnsmenu = menu Vhffs::Panel::DNS($data);
			$projecttemplate->param( DNS_MENU => $dnsmenu );
		}

		# Mail
		if( $vhffs->get_config->use_mail == 1 )
		{
			my $mailmenu = menu Vhffs::Panel::Mail($data);
			$projecttemplate->param( MAIL_MENU => $mailmenu );
		}

		# Mailing list
		if( $vhffs->get_config->use_mailing == 1 )
		{
			my $mailingmenu = menu Vhffs::Panel::Mailinglist($data);
			$projecttemplate->param( MAILINGLIST_MENU => $mailingmenu );
		}

		# Large files
		if( $vhffs->get_config->use_largefile == 1 )
		{
			$menu = menu Vhffs::Panel::LargeFile($data);
			$projecttemplate->param( LARGEFILE_MENU => $menu );
		}

		# Download repository
		if( $vhffs->get_config->use_repository == 1 )
		{
			$menu = menu Vhffs::Panel::Repository($data);
			$projecttemplate->param( REPOSITORY_MENU => $menu );
		}

		$menutemplate->param( PROJECT_MENU => $projecttemplate->output );
	}

	return $menutemplate;
}

1;
