#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


package Vhffs::Panel::Web;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Services::Httpd;
use Vhffs::Constants;
use Vhffs::Functions;

sub getall_web_to_moderate
{
	my( $main , $query , $request);
	$main = shift;
	$query = "SELECT w.servername , o.description ,  u.username , g.groupname , o.object_id FROM vhffs_httpd w, vhffs_object o , vhffs_users u , vhffs_groups g  WHERE u.uid=w.owner_uid AND g.gid=w.owner_gid AND w.object_id=o.object_id AND o.state='".Vhffs::Constants::WAITING_FOR_VALIDATION."'";
	$request = $main->{'db'}->{'DB_READ'}->prepare( $query );

	return undef if ( $request->execute <= 0 );
	return( $request->fetchall_hashref('servername') );
}


sub getall_web_per_group
{
        my ( $group , $main ) =@_ ;

        return undef if ( $group->fetch < 0 );

        my $query = "SELECT w.servername, w.object_id, o.state  FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id AND w.owner_gid='".$group->get_gid."'";
        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

        return undef if ( $request->execute() <= 0);

        return( $request->fetchall_hashref('servername') );
}


sub getall_webs
{
	my $main = shift;
	my $name = shift;

	my $query;

	if( defined $name )
	{
		$query = "SELECT w.servername, w.object_id, o.state  FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id AND w.servername LIKE '".$name."'";
	}
	else
	{
		$query = "SELECT w.servername, w.object_id, o.state  FROM vhffs_httpd w, vhffs_object o WHERE o.object_id=w.object_id";
	}
        my $request = $main->{'db'}->{'DB_READ'}->prepare( $query ) or return -1;

        return undef if ( $request->execute() <= 0);

        return( $request->fetchall_hashref('servername') );
}


sub create_web
{
        my( $main , $servername , $user , $group ) = @_;

        return -1 if( $user->fetch < 0 );
        return -2 if( $group->fetch < 0 );

        my $web = new Vhffs::Services::Httpd( $main , $servername , $user , $group );
		return undef if( ! defined $web );
		$web->set_user( $user );
		$web->set_group( $group );

        return undef if ( $web->create < 0 );

        return undef if ( Vhffs::Acl::add_acl( $user , $web , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
        return undef if( Vhffs::Acl::add_acl( $group , $web , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

        return $web;
}



sub menu
{
	my ( $class , $data ) = @_;

	my $vhffs = $data->{'vhffs'};
	my $session = $data->{'session'};
	my $user = $data->{'user'};
	my $group = $data->{'group'};
	my $cgi = $data->{'cgi'};
    my $templatesdir = $vhffs->get_config->get_templatedir;
	

	my $template = new HTML::Template( filename => $templatesdir."/web/menu.tmpl" );
	$template->param( TEXT_CREATE => gettext("Create") );
	$template->param( TEXT_WEB => gettext("Web Areas") );

	my $sites = Vhffs::Services::Httpd::getall( $vhffs , undef , undef , $group );
	my $site;
	my $output = "";
	my $subtemplate;
	my $statsurl;

	foreach $site ( @{$sites} )
	{
        	if( $site->get_status == Vhffs::Constants::ACTIVATED )
	        {
			$subtemplate = new HTML::Template( filename => "$templatesdir/web/menu_sub.tmpl" );
			$subtemplate->param( NAME => $site->get_servername);
			$subtemplate->param( STATSURL => $vhffs->get_config->get_panel_statsurl) if( defined $vhffs->get_config->get_panel_statsurl );
			$subtemplate->param( HISTORY => gettext("History"));
			$subtemplate->param( OID => $site->get_oid );
			$output .= $subtemplate->output;
	        }
	       	else
        	{
			$subtemplate = new HTML::Template( filename => "$templatesdir/web/menu_sub_wait.tmpl" );
			$subtemplate->param( NAME => $site->get_servername );
			$subtemplate->param( REASON => Vhffs::Functions::status_string_from_status_id( $site->get_status) );
            $subtemplate->param( HISTORY => gettext("History"));
            $subtemplate->param( OID => $site->get_oid );
			$output .= $subtemplate->output;
			}
	}	

	$template->param( SUB_WEB => $output );

	return $template->output;
}

1;
