#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Httpd;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $type = $cgi->param("TYPE");
my $name = $cgi->param("NAME");
my $template;

my $message;
my $object;
my $ok = 1;
my $title;

my $g;
my $u;

my $templatedir = $vhffs->get_config->get_templatedir;

#First, we instanciate an Object, according to the variable $type
if( $type eq "web" )
{
	$object = new Vhffs::Services::Httpd( $vhffs , $name , $user , $group );
}
elsif( $type eq "dns" )
{
	$object = new Vhffs::Services::DNS( $vhffs , $name , $user , $group );
}
elsif( $type eq "mysql" )
{
	$object = new Vhffs::Services::Mysql( $vhffs , $name , $user , $group );
}
elsif( $type eq "pgsql" )
{
	$object = new Vhffs::Services::Postgres( $vhffs , $name , $user , $group );
}
elsif( $type eq "cvs" )
{
	$object = new Vhffs::Services::Cvs( $vhffs , $name  );
}
elsif( $type eq "svn" )
{
	$object = new Vhffs::Services::Svn( $vhffs , $name , $user , $group );
}
elsif( $type eq "ns" )
{
	$object = new Vhffs::Services::DNS( $vhffs , $name  );
}
elsif( $type eq "mail" )
{
	$object = new Vhffs::Services::Mail( $vhffs , $name  );
}
elsif( $type eq "ml" )
{
	my( $lpart , $domain ) = split( /\@/ , $name );
	$object = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain );
}
elsif( $type eq "largefile" )
{
	$object = new Vhffs::Services::LargeFile( $vhffs , $name , $user , $group );
}
elsif( $type eq "repository" )
{
	$object = new Vhffs::Services::Repository( $vhffs , $name , $user , $group );
}
else
{
	#If the type was not found, we juste print an error
	$ok = 0;
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "This type of object is not treated in the panel.");
	$template->param( MESSAGE => $message );
}

# $ok = 1 , so, ths object is instanciate
if( $ok == 1 )
{
	if( ( ! defined $object ) || ( $object->fetch < 0 ) )
	{
		$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
		$message = sprintf( gettext("Cannot get informations on this object %s %s"), $type, $name);
		$template->param( MESSAGE => $message );
	
	}
	elsif( ( Vhffs::Acl::what_perm_for_user( $user , $object , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
	{
		$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
		$message = gettext("You're not allowed to view this object's ACL");
		$template->param( MESSAGE => $message );
	}
	else
	{
		$template = new HTML::Template( filename => $templatedir."/acl/view.tmpl" );
	
		$template->param( TITLE => gettext("ACL Administration for : ".$object->get_title) );

		$template->param( TEXT_USERNAME => gettext("Username" ) . ": ");
		$template->param( TEXT_GROUPNAME => gettext("Groupname" ) . ": ");


		$template->param( VALUE_ACL_DENIED => Vhffs::Constants::ACL_DENIED );
		$template->param( VALUE_ACL_VIEW => Vhffs::Constants::ACL_VIEW );
		$template->param( VALUE_ACL_MODIFY => Vhffs::Constants::ACL_MODIFY );
		$template->param( VALUE_ACL_MANAGEACL => Vhffs::Constants::ACL_MANAGEACL );
		$template->param( VALUE_ACL_DELETE => Vhffs::Constants::ACL_DELETE );


        $template->param( TEXT_ACL_DENIED => gettext("Can't access") );
        $template->param( TEXT_ACL_VIEW => gettext("Can view this service") );
        $template->param( TEXT_ACL_MODIFY => gettext("Can modify this service") );
        $template->param( TEXT_ACL_MANAGEACL => gettext("Can manage ACL for this service") );
        $template->param( TEXT_ACL_DELETE => gettext("Can destroy this service") );
        
		$template->param( TEXT_ACL_LEVEL => gettext("ACL level") );
        
		$template->param( OIDDST => $object->get_oid );
		$template->param( SEND => gettext("Send it") );

		my $output_user = "";
		my $output_group = "";
		my $user_rights = Vhffs::Acl::getall_acl_for_user_per_object( $object , $vhffs );
		my $group_rights = Vhffs::Acl::getall_acl_for_group_per_object( $object , $vhffs );

		my $subtemplate;

		foreach( keys %{$user_rights} )
		{
			$u = new Vhffs::User( $vhffs , $user_rights->{$_}{'username'} , '401' );
			$u->fetch;

			$subtemplate = new HTML::Template( filename => $templatedir."/acl/view_each.tmpl" );
			$subtemplate->param( NAME => $user_rights->{$_}{'username'} );
			$subtemplate->param( TEXT_ACL_DENIED => gettext("Can't access") );
			$subtemplate->param( TEXT_ACL_VIEW => gettext("Can view this service") );
			$subtemplate->param( TEXT_ACL_MODIFY => gettext("Can modify this service") );
			$subtemplate->param( TEXT_ACL_MANAGEACL => gettext("Can manage ACL for this service") );
			$subtemplate->param( TEXT_ACL_DELETE => gettext("Can destroy this service") );
			$subtemplate->param( SEND => gettext("Modify this ACL") );

			$subtemplate->param( VALUE_ACL_DENIED => Vhffs::Constants::ACL_DENIED );
			$subtemplate->param( VALUE_ACL_VIEW => Vhffs::Constants::ACL_VIEW );
			$subtemplate->param( VALUE_ACL_MODIFY => Vhffs::Constants::ACL_MODIFY );
			$subtemplate->param( VALUE_ACL_MANAGEACL => Vhffs::Constants::ACL_MANAGEACL );
			$subtemplate->param( VALUE_ACL_DELETE => Vhffs::Constants::ACL_DELETE );

			if( $user_rights->{$_}{'perm'} == Vhffs::Constants::ACL_DELETE )
			{
				$subtemplate->param( DELETE_SELECTED => "selected" );
			}
			elsif( $user_rights->{$_}{'perm'} == Vhffs::Constants::ACL_MANAGEACL )
			{
				$subtemplate->param( MANAGEACL_SELECTED => "selected" );
			}
			elsif( $user_rights->{$_}{'perm'} == Vhffs::Constants::ACL_MODIFY )
			{
				$subtemplate->param( MODIFY_SELECTED => "selected" );
			}
			elsif( $user_rights->{$_}{'perm'} == Vhffs::Constants::ACL_VIEW )
			{
				$subtemplate->param( VIEW_SELECTED => "selected" );
			}
			elsif( $user_rights->{$_}{'perm'} == Vhffs::Constants::ACL_DENIED )
			{
				$subtemplate->param( DENIED_SELECTED => "selected" );
			}

			$subtemplate->param( OIDDST => $object->get_oid );
			$subtemplate->param( OIDSRC => $u->get_oid );

			$output_user .= $subtemplate->output;
		}

        foreach( keys %{$group_rights} )
        {   
			$g = new Vhffs::Group( $vhffs , $group_rights->{$_}{'groupname'} , '401' );
			$g->fetch;

            $subtemplate = new HTML::Template( filename => $templatedir."/acl/view_each.tmpl" );
            $subtemplate->param( NAME => $group_rights->{$_}{'groupname'} );

            $subtemplate->param( TEXT_ACL_DENIED => gettext("Can't access") );
            $subtemplate->param( TEXT_ACL_VIEW => gettext("Can view this service") );
            $subtemplate->param( TEXT_ACL_MODIFY => gettext("Can modify this service") );
            $subtemplate->param( TEXT_ACL_MANAGEACL => gettext("Can manage ACL for this service") );
            $subtemplate->param( TEXT_ACL_DELETE => gettext("Can destroy this service") );
            $subtemplate->param( SEND => gettext("Modify this ACL") );


			$subtemplate->param( VALUE_ACL_DENIED => Vhffs::Constants::ACL_DENIED );
			$subtemplate->param( VALUE_ACL_VIEW => Vhffs::Constants::ACL_VIEW );
			$subtemplate->param( VALUE_ACL_MODIFY => Vhffs::Constants::ACL_MODIFY );
			$subtemplate->param( VALUE_ACL_MANAGEACL => Vhffs::Constants::ACL_MANAGEACL );
			$subtemplate->param( VALUE_ACL_DELETE => Vhffs::Constants::ACL_DELETE );


            if( $group_rights->{$_}{'perm'} == Vhffs::Constants::ACL_DELETE )
            {   
                $subtemplate->param( DELETE_SELECTED => "selected" );
            }
            elsif( $group_rights->{$_}{'perm'} == Vhffs::Constants::ACL_MANAGEACL )
            {   
                $subtemplate->param( MANAGEACL_SELECTED => "selected" );
            }
            elsif( $group_rights->{$_}{'perm'} == Vhffs::Constants::ACL_MODIFY )
            {   
                $subtemplate->param( MODIFY_SELECTED => "selected" );
            }
            elsif( $group_rights->{$_}{'perm'} == Vhffs::Constants::ACL_VIEW )
            {   
                $subtemplate->param( VIEW_SELECTED => "selected" );
            }
            elsif( $group_rights->{$_}{'perm'} == Vhffs::Constants::ACL_DENIED )
            {   
                $subtemplate->param( DENIED_SELECTED => "selected" );
            }
            
			$subtemplate->param( OIDDST => $object->get_oid );
			$subtemplate->param( OIDSRC => $g->get_oid );

            $output_group .= $subtemplate->output;
        }


		$template->param( USERS_TABLE => $output_user );	
		$template->param( GROUPS_TABLE => $output_group );	
	
	
	}
}

display Vhffs::Panel::Main($panel, $template->output);
