#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::User;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};

my $message;

my $mail = $cgi->param( "MAIL" );
my $firstname = $cgi->param( "FIRSTNAME" );
my $lastname = $cgi->param( "LASTNAME" );
my $city = $cgi->param( "CITY" );
my $zipcode = $cgi->param( "ZIPCODE" );
my $country = $cgi->param( "COUNTRY" );
my $address = $cgi->param( "ADDRESS" );
my $pass1 = $cgi->param("PASSWORD1");
my $pass2 = $cgi->param("PASSWORD2");

my $theme = $cgi->param( "THEME" );
my $lang = $cgi->param( "LANG" ); 

my $pwd_change = 0;
my $mail_change = 0;
my $templatedir = $vhffs->get_config->get_templatedir;

# We set informations user fill in the form


my $cookie = CGI->cookie(theme => $theme);
Vhffs::Panel::User::set_theme( $user, $theme );

my $cookie2 = CGI->cookie(language => $lang);
Vhffs::Panel::User::set_lang( $user, $lang );


# Commit all the changes for the current user
if( ( ! defined $firstname ) || ( ! defined $lastname ) || ( ! defined $city ) || ( ! defined $mail ) || ( ! defined $zipcode ) || ( ! defined $country ) || ( ! defined $address ) )
{
	$message = gettext( "CGI Error!" );
}
elsif( ! ( $zipcode =~ /^[\w\d\s\-]+$/ ) )
{
	$message = gettext( "Zipcode is not correct !" );
}
elsif( $pass1 ne $pass2 )
{
	$message = gettext( "Passwords don't match" );
}
else
{
	$user->set_firstname(  $firstname );
	$user->set_lastname(  $lastname );
	$user->set_city(  $city );
	$user->set_zipcode( $zipcode );
	$user->set_country( $country );
	$user->set_address( $address );

	if( ( length( $pass1 ) > 1 ) && ( $pass1 eq $pass2 ) )
	{ 
		$pwd_change = 1;
		$user->set_password( $pass1 );
	}

	my $prevmail = $user->get_mail();
	if( $prevmail ne $mail )
	{
		$mail_change = 1;	
		$user->set_mail( $mail );
		my $subject = gettext("Mailbox modified");
		my $content = sprintf( gettext("Hello %s %s,\n\nYou changed your email, here are your new personal information :\n\nUser: %s\nMail: %s\n\nVHFFS administrators\n"), $user->get_firstname, $user->get_lastname, $user->get_username, $user->get_mail);
		$user->send_mail_user( $subject, $content );
	}

	if( $user->commit < 0 )
	{
		$message = gettext("An error occured while updating the user account");
	}
	else
	{
		$message = gettext("User Successfully modified") . "<br>";
	}

	my $mu;	
	if( $vhffs->get_config->use_mailuser == 1 )
	{
		use Vhffs::Services::MailUser;
		$mu = init Vhffs::Services::MailUser( $vhffs , $user );
	}

	# check if mu is not a negative integer
	if( defined $mu  &&  $mu >= 0  &&  $mu->available > 0 )  {

		my $mail_activate = $cgi->param( "mail_activate" );
		my $nospam = $cgi->param( "mail_nospam" );
		my $novirus = $cgi->param( "mail_novirus" );
		if( ( defined $nospam ) && ( $nospam eq "on" ) )
		{
			$nospam = 1;
		}
		else
		{
			$nospam = 0;
		}
		if( ( defined $novirus ) && ( $novirus eq "on" ) )
		{
			$novirus = 1;
		}
		else
		{
			$novirus = 0;
		}

		if( ( defined $mail_activate ) && ( $mail_activate eq "on" ) )
		{
			my $usage = $cgi->param( "mail_usage" );
			if( ! defined $usage )
			{
				$message = gettext("You must choose a method for your mail");	
			}
			elsif( $usage == 1 )
			{

				#In this case, we treat for popable accounts
				if( $mu->exists_box == 0 )
				{
					if( $pwd_change == 0 )
					{
						$message = gettext("Error ! You MUST provide a password in your account when you create your popable account");
					}
					elsif( ($mu->addbox ($pass1 )) < 0 )
					{
						$message = gettext("An error occured while adding the box");
					}
					elsif( ( $nospam == 1 ) && ( $mu->change_spam_status < 0 ) )
					{
						$message = gettext("An error occured while adding the box (anti-spam adding)");
					}
					elsif( ( $novirus == 1 ) && ( $mu->change_virus_status < 0 ) )
					{
						$message = gettext("An error occured while adding the box (anti-virus adding)");
					}
					else
					{
						$message .= "<br/>";
						$message .= gettext("Mailbox successfully added");
					}
				}
				else
				{
					# The use changed his password, we must update password for mail
					if( $pwd_change == 1 )
					{
						$mu->delbox;
						$mu->addbox( $pass1 );
					}

					# We change the spam status. if the spam status changed
					if( $vhffs->get_config->use_nospam == 1 )
					{
						if( $nospam != $mu->use_nospam )
						{
							if( $mu->change_spam_status == 1 )
							{
								$message .= gettext( "Change spam protection status for your account\n" );
								$message .= "<br/>";
							}
							else
							{
								$message .= gettext( "Error for spam protection\n" );
								$message .= "<br/>";
							}
						}
					}

					# As spam, the virus status changes only if the user changed values
					if( $vhffs->get_config->use_novirus == 1 )
					{
						if( $novirus != $mu->use_novirus )
						{
							if( $mu->change_virus_status == 1 )
							{
								$message .= gettext( "Change anti-virus status for your account\n" );
								$message .= "<br/>";
							}
							else
							{
								$message .= gettext( "Error for virus protection\n" );
								$message .= "<br/>";
							}
						}
					}
				}
			}
			elsif( $usage == 2 ) 
			{
				#Here, we create the forward
				my $ad = $user->get_mail;
				if(  $mu->exists_forward == 0 )
				{
					if( ! defined $ad )
					{
						$message = "<br>" . gettext("There is a problem with the address you filled in your profile, unable to add forwarding");
					}
					else
					{
						if( $mu->addforward( $user->get_mail ) < 0)
						{
							$message = gettext("An error occured while adding the forwarding");
						}
					}
				}
				else
				{
					#Here, we update the forward
					if( $mail_change ==1 )
					{
						$mu->delforward;
						if( $mu->addforward( $mail ) < 0 )
						{
							$message .= "<br>" . gettext("An error occured while the forwarding");
							
						}
					}
				}
			}
		}
		else
		{
			$mu->delbox;
			$mu->delforward;
		}
	}
	
}
my $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
$template->param( MESSAGE => $message );

set_refresh_url Vhffs::Panel::Main($panel, "/user/prefs.pl", 0);
display Vhffs::Panel::Main($panel, $template->output, $cookie, $cookie2);
