#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
    exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $groupname = $panel->{'groupname'};
my $templatedir = $vhffs->get_config->get_templatedir;

my $template = new HTML::Template( filename => $templatedir."/web/create.tmpl" );
my $config = $vhffs->get_config;
my $default_domain = $config->get_default_apache_domain;
my $servername;


if( defined $default_domain )
{
	$servername = gettext("<new site>.") . $default_domain;	
	$template->param( SERVERNAME_VALUE => $servername);
}

$template->param( TITLE => gettext("Create a web space") );
$template->param( SERVERNAME_TEXT => gettext("Adress (ServerName directive)") );
$template->param( SERVERNAME_WARNING => gettext("Be careful, if you want create www.domain.tld, you should create a webspace with servername as domain.tld. VHFFS redirect all request from www.domain.tld to domain.tld") );
$template->param( GROUP_NAME => gettext("Group owning this web space") );


$template->param( GROUP => $group->get_groupname );
$template->param( SEND => gettext("Send") );
$template->param( MOTIVATION => gettext("Tell us what the use of this web space will be") );

display Vhffs::Panel::Main($panel, $template->output);
