#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use Vhffs::Services::LargeFile;
use Vhffs::Robots;
use Vhffs::Functions;
use Vhffs::Main;
use locale;
use Locale::gettext;
use File::Copy;


my $vhffs = init Vhffs::Main;

lock( $vhffs );

my $files = Vhffs::Services::LargeFile::getall( $vhffs , Vhffs::Constants::TO_DELETE , undef, undef );
my $file;
my $groupname;
my $queue_path;
my $completed_path;
my $pass;

foreach $file ( @{$files} )
{
	$groupname = $file->get_group->get_groupname;

    $queue_path = $vhffs->get_config->get_datadir. "/largefile/queue/" . substr( $groupname , 0 , 1 ) . "/" . substr( $groupname , 1 , 1 ) . "/" . $groupname . "/" . $file->get_filename ; 
    $completed_path = $vhffs->get_config->get_datadir. "/largefile/completed/" . substr( $groupname , 0 , 1 ) . "/" . substr( $groupname , 1 , 1 ) . "/" . $groupname . "/" . $file->get_filename ; 

	if( -f $queue_path )
	{
		unlink( $queue_path );
	}
	if( -f $completed_path )
	{
		unlink( $queue_path );
	}

	$file->add_history( gettext( "Will try to delete the object from the platform" ) );
	if( $file->delete != 1 )
	{
		$file->add_history( gettext( "Error when delete the file from platform" ) );
	}
}

unlock( $vhffs );

exit 0;

