/*
 *     autokill - A program to kill all process running during a certain
 *                period of time or using too much cpu
 *
 *  Copyright (C) 2006 Sylvain Rochet
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <dirent.h>
#include <sys/types.h>
#include <signal.h>
#include <time.h>
#include <sys/time.h>
#include <pwd.h>

#define FALSE 0
#define TRUE !FALSE

// Assume you are using a system with jiffies at 100 HZ (all linux >= 2.4 kernels)
#define HERTZ 100.0

// All process between MINUID included and MAXUID included will be killed
#define MINUID 10000
#define MAXUID 65000

// Interval between checks, in centiseconds (100 = 1 sec)
#define WAITTIME 100

// The maximum time the process are allowed to run, in jiffies
#define MAXRUNTIMESIGTERM 30000
#define MAXRUNTIMESIGKILL 30120

// The maximum cpu time the process are allowed to use, in jiffies
#define MAXCPUTIMESIGTERM 3100
#define MAXCPUTIMESIGKILL 3210

// Demo mode ?
#define DEMOMODE FALSE

// Daemonize ?
#define DAEMONIZE TRUE

// Logs ?
#define LOGENABLE TRUE
#define LOGFILE "/var/log/autokill.log"



void addlogline(char *line);

int main(int argc, char *argv[])  {

	if(LOGENABLE)  {
		if(DEMOMODE) addlogline("Starting autokill in DEMOMODE");
		else addlogline("Starting autokill");
	}

	if(DAEMONIZE && fork()) exit(0);

	while(1)  {
		char path[256], data[8192];
		FILE *f;
		int br;
		unsigned long long uptime;
		DIR *d;
		struct dirent *dir;

		// just wait, nothing more, really, I am not kidding, you can trust me
		// be serious, if I tell you that it is only a stupid wait inside an
		// infinite loop it is probably true, it is not an uncommon thing
		// as far as I know !
		// ok... give up... and let me do my job right now, want you ?
		if(WAITTIME/100) sleep(WAITTIME/100);
		if(WAITTIME%100) usleep((WAITTIME%100)*10000);

		// read uptime
		f = fopen("/proc/uptime", "r");
		if(!f) continue;
		br = fread(data, 1, 8192, f);
		fclose(f);
		if(!br) continue;

		uptime = (unsigned long long)(atof(data)*HERTZ);
		if(!uptime) continue;

		// search running process
		d = opendir("/proc");
		if(!d) continue;

		while( (dir = readdir(d) ) )  {
			int i, c, s, pid, zombie;
			unsigned long long uid, starttime, rtime, cputime;
			int signal;
			char *signame;

			// discard non directory and non numerical name
			if(dir->d_type != DT_DIR || dir->d_name[0] < '0' || dir->d_name[0] > '9')  continue;

			pid = atoi(dir->d_name);
			if(!pid) continue;

			// read /proc/pid/status
			snprintf(path, 256, "/proc/%d/status", pid);
			f = fopen(path, "r");
			if(!f) continue;
			br = fread(data, 1, 8192, f);
			fclose(f);
			if(!br) continue;

			uid = -1;
			for(i = 0 ; i < br-4 ; i++)  {
				if( (i == 0 || data[i-1] == '\n') && data[i] == 'U' && data[i+1] == 'i' && data[i+2] == 'd')  {
					for(; i < br ; i++)  {
						if(data[i] >= '0' && data[i] <= '9')  {
							uid = atoll(data+i);
							break;
						}
					}
					break;
				}
			}

			if(uid < MINUID || uid > MAXUID) continue;

			// read /proc/pid/stats
			snprintf(path, 256, "/proc/%d/stat", pid);
			f = fopen(path, "r");
			if(!f) continue;
			br = fread(data, 1, 8192, f);
			fclose(f);
			if(!br) continue;

			starttime = -1;
			zombie = FALSE;
			cputime = 0;
			for(i = c = s = 0 ; i < br ; i++)  {
				if(data[i] == ' ' || data[i] == '\t')  {
					s = 0;
				} else {
					if(!s) {
						// triggered
						s = 1;
						c++;

						if(c == 3)  {
							if(data[i] == 'Z')  {
								zombie = TRUE;
								break;
							}
						}

						if(c >= 14 && c <= 17)  {
							cputime += atoll(data+i);
						}

						if(c == 22)  {
							starttime = atoll(data+i);
							break;
						}
					}
				}
			}

			if(zombie) continue;
			if(starttime < 0) continue;

			signal = -1;
			// check cputime
			if(cputime > MAXCPUTIMESIGTERM)  {

				if(cputime > MAXCPUTIMESIGKILL)  {
					signal = SIGKILL;
					signame = "SIGKILL";
				}
				else  {
					signal = SIGTERM;
					signame = "SIGTERM";
				}
			}

			// check running time
			rtime = uptime - starttime;
			if(rtime > MAXRUNTIMESIGTERM)  {

				if(rtime > MAXRUNTIMESIGKILL)  {
					signal = SIGKILL;
					signame = "SIGKILL";
				}
				else  {
					signal = SIGTERM;
					signame = "SIGTERM";
				}
			}

			if(signal >= 0)  {
				if(LOGENABLE)  {
					char line[128];
					struct passwd *pw;
 					char *name, *demo;

					pw = getpwuid(uid);
					if(pw) name = pw->pw_name;
					else name = "unknown";

					if(DEMOMODE) demo = "[DEMO MODE] ";
					else demo = "";

					snprintf(line, 128, "%sSend %s to process %d, owned by %s(%d), cpu time %.2f sec, running time %.2f sec", demo, signame, pid, name, (int)uid, cputime/HERTZ, rtime/HERTZ);
					addlogline(line);
				}

				if(!DEMOMODE) kill(pid, signal);
			}

		}
		closedir(d);
	}

	return 0;
}


void addlogline(char *line)  {

	FILE *lf;

	struct timeval tv;
	char date[64];

	gettimeofday(&tv, NULL);
	ctime_r(&tv.tv_sec, date);
	date[strlen(date)-1] = '\0';

	lf = fopen(LOGFILE, "a");
	if(lf)  {
		fprintf(lf, "%s: %s\n", date, line);
		fclose(lf);
	}
	else  {
		// use stdout if logfile is not available
		fprintf(stdout, "%s: %s\n", date, line);
	}
}
